                  ##### Variable selection and data filtering #####


library(dismo)
library(ade4)
library(ggplot2)
library(sp)
library(raster)
library(NbClust)
library(factoextra)
library(cluster)
library(fpc)
library(plyr)
library(dplyr)
library(data.table)
library(rlang)
library(rgdal)
library(rgeos)
library(tibble)

###################################################################################
##  1.Sampling response variables (presence data) domesticated
###################################################################################

#### SAMPLE DOMESTICATED ENSET DATA #####


#read txt file with domesticated enset records
enset_dom_extrbp<-read.csv("PATH/SDM/Data/Location/enset_dom_new_extrbp.csv",header = TRUE)

#devide BIOCLIM variables by sd
e_dom_bio01_sd<- sapply(enset_dom_extrbp$ch_bio01,function(x){x/sd(enset_dom_extrbp$ch_bio01)})
e_dom_bio02_sd<- sapply(enset_dom_extrbp$ch_bio02,function(x){x/sd(enset_dom_extrbp$ch_bio02)})
e_dom_bio03_sd<- sapply(enset_dom_extrbp$ch_bio03,function(x){x/sd(enset_dom_extrbp$ch_bio03)})
e_dom_bio04_sd<- sapply(enset_dom_extrbp$ch_bio04,function(x){x/sd(enset_dom_extrbp$ch_bio04)})
e_dom_bio05_sd<- sapply(enset_dom_extrbp$ch_bio05,function(x){x/sd(enset_dom_extrbp$ch_bio05)})
e_dom_bio06_sd<- sapply(enset_dom_extrbp$ch_bio06,function(x){x/sd(enset_dom_extrbp$ch_bio06)})
e_dom_bio07_sd<- sapply(enset_dom_extrbp$ch_bio07,function(x){x/sd(enset_dom_extrbp$ch_bio07)})
e_dom_bio08_sd<- sapply(enset_dom_extrbp$ch_bio08,function(x){x/sd(enset_dom_extrbp$ch_bio08)})
e_dom_bio09_sd<- sapply(enset_dom_extrbp$ch_bio09,function(x){x/sd(enset_dom_extrbp$ch_bio09)})
e_dom_bio10_sd<- sapply(enset_dom_extrbp$ch_bio10,function(x){x/sd(enset_dom_extrbp$ch_bio10)})
e_dom_bio11_sd<- sapply(enset_dom_extrbp$ch_bio11,function(x){x/sd(enset_dom_extrbp$ch_bio11)})
e_dom_bio12_sd<- sapply(enset_dom_extrbp$ch_bio12,function(x){x/sd(enset_dom_extrbp$ch_bio12)})
e_dom_bio13_sd<- sapply(enset_dom_extrbp$ch_bio13,function(x){x/sd(enset_dom_extrbp$ch_bio13)})
e_dom_bio14_sd<- sapply(enset_dom_extrbp$ch_bio14,function(x){x/sd(enset_dom_extrbp$ch_bio14)})
e_dom_bio15_sd<- sapply(enset_dom_extrbp$ch_bio15,function(x){x/sd(enset_dom_extrbp$ch_bio15)})
e_dom_bio16_sd<- sapply(enset_dom_extrbp$ch_bio16,function(x){x/sd(enset_dom_extrbp$ch_bio16)})
e_dom_bio17_sd<- sapply(enset_dom_extrbp$ch_bio17,function(x){x/sd(enset_dom_extrbp$ch_bio17)})
e_dom_bio18_sd<- sapply(enset_dom_extrbp$ch_bio18,function(x){x/sd(enset_dom_extrbp$ch_bio18)})
e_dom_bio19_sd<- sapply(enset_dom_extrbp$ch_bio19,function(x){x/sd(enset_dom_extrbp$ch_bio19)})


e_dom_bio_sd2<-cbind(e_dom_bio01_sd, e_dom_bio02_sd, e_dom_bio03_sd, e_dom_bio04_sd, e_dom_bio05_sd, e_dom_bio06_sd, e_dom_bio07_sd, e_dom_bio08_sd, e_dom_bio09_sd, 
                     e_dom_bio10_sd, e_dom_bio11_sd, e_dom_bio12_sd, e_dom_bio13_sd, e_dom_bio14_sd, e_dom_bio15_sd, e_dom_bio16_sd, e_dom_bio17_sd, e_dom_bio18_sd, e_dom_bio19_sd)


##pca##
e_dom_bio_pca2<-dudi.pca(e_dom_bio_sd2,scannf = FALSE,nf=2)
plot(e_dom_bio_pca2$li)

e_dom_bio_pca_unique<-unique(e_dom_bio_pca$li)
write.csv(e_dom_bio_pca_unique,"PATH/SDM/Data/Location/enset_dom_pca_unique.csv")
e_dom_bio_pca_unique<-read.csv("PATH/SDM/Data/Location/enset_dom_pca_unique.csv")
##eiclidian distance matrix##
e_dom_bio_dist<-dist(e_dom_bio_pca_unique,method="euclidean")

e_dom_bio_distm2<-data.matrix(e_dom_bio_dist)





##### sample for testing/training #####

##wss function to determine optimal number of clusters##
wss <- rep(0, 60)
wss[1] <- (60 - 1) * sum(sapply(e_dom_bio_distm2, var))
for (i in 2:60)
  wss[i] <- sum(kmeans(e_dom_bio_distm2,
                       centers = i)$withinss)
plot(1:60, wss, type = "b", xlab = "Number of groups",   
     ylab = "Within groups sum of squares")



##k means clustering with 30 centres##
e_dom_bio_kmeans2<-kmeans(e_dom_bio_dist,centers=30,nstart = 50)

plotcluster(e_dom_bio_pca_unique,e_dom_bio_kmeans2$cluster)
cluster_kmeans2<-data.frame(e_dom_bio_kmeans2$cluster)


# join cluster_kmeans2, enset_dom_extrbp, e_dom_pca_unique
e_dom_pca_unique<-read.csv("PATH/SDM/Data/Location/enset_dom_pca_unique.csv")
enset_dom_extrbp<-read.csv("PATH/SDM/Data/Location/enset_dom_new_extrbp.csv")
enset_dom_extrbp_pcaunique<-setDT(enset_dom_extrbp)[Field%in%e_dom_pca_unique$Field]
enset_dom_pcaclust<-cbind(enset_dom_extrbp_pcaunique[,1:24],e_dom_bio_pca_unique$Axis1,e_dom_bio_pca_unique$Axis2, cluster_kmeans2$e_dom_bio_kmeans2.cluster)
names(enset_dom_pcaclust)[25:27]<-c("Axis1","Axis2","Cluster")

##sample 2 random rows per cluster for training/testing##
enset_dom_sample2<-read.csv("PATH/SDM/R/Data/presences/sample/enset_dom_sample2.csv")
enset_dom_sample90<-ddply(enset_dom_sample2,.(Cluster),function(x) x[sample(nrow(x),3),])
enset_dom_sample60<-ddply(enset_dom_sample90,.(Cluster),function(x) x[sample(nrow(x),2),])
write.csv(enset_dom_sample60, "PATH/SDM/R/Data/presences/sample/enset_dom_sample60.csv")


##sample evaluation sample
e_dom_eval_sample60<-setDT(enset_dom_sample90)[!Field%in%enset_dom_sample60$Field]
write.csv(e_dom_eval_sample60, "PATH/SDM/Data/Location/e_dom_eval_sample60.csv")








###################################################################################
## 2.Explanatory Variable selection
###################################################################################


###### select07 ########

#stack bioclim variables of current climate for reference area
Expl_reference= stack( ch_bio01_reference, 
                       ch_bio02_reference,
                       ch_bio03_reference, 
                       ch_bio04_reference, 
                       ch_bio05_reference, 
                       ch_bio06_reference, 
                       ch_bio07_reference,
                       ch_bio08_reference,
                       ch_bio09_reference,
                       ch_bio10_reference,
                       ch_bio11_reference,
                       ch_bio12_reference,
                       ch_bio13_reference,
                       ch_bio14_reference,
                       ch_bio15_reference,
                       ch_bio16_reference,
                       ch_bio17_reference,
                       ch_bio18_reference,
                       ch_bio19_reference)

##transform expl_reference to data frame
Expl_reference_df<-as.data.frame(Expl_reference, na.rm = TRUE, xy = TRUE, melt=TRUE)
names(Expl_reference_df)[3:21]<-c("ch_bio01","ch_bio02","ch_bio03","ch_bio04","ch_bio05","ch_bio06","ch_bio07","ch_bio08","ch_bio09","ch_bio10",
                                  "ch_bio11","ch_bio12","ch_bio13","ch_bio14","ch_bio15","ch_bio16","ch_bio17","ch_bio18","ch_bio19")
gg<-sre(Response = E_ventricosum_dom,
        Explanatory = enset_dom_pcaclust_sample2[,6:24],
        NewData = Expl_reference_df[,3:21],
        Quant=0.025,
        return_extremcond = FALSE)

plot(gg)
gg
Expl_reference_df_gg<-cbind(gg,Expl_reference_df)

pa<-Expl_reference_df_gg [Expl_reference_df_gg$Response==0, ]
pa120<-sample_n(pa,120)
pa120<-cbind(pa120,"FALSE")
names(pa120)[23]<-c("Cluster_sample")
pa120_c<-cbind(pa120[4:23])
p120_c<-cbind(enset_dom_pcaclust_sample2[6:24],enset_dom_pcaclust_sample2[28])
pa120_c<-rbind(pa120_c,p120_c)


##### use glm model to calculate univariate variable importance#####
var.imp <- function (predictor, response)
{
  AIC(glm(response ~ predictor+I(predictor^2), binomial))
}

aic_imp <- apply(pa120_c[,1:19], 2, var.imp, response= pa120_c$Cluster_sample)

sort(aic_imp)



######select uncorrelated variables########

select07 <- function(pred_names, response_name, data, cor_mat=NULL, threshold=0.7){
  
  # Function for calculating AIC - we use univariate GLMs with linear and quadratic terms
  var.imp <- function (predictor, response)
  {
    AIC(glm(response ~ predictor+I(predictor^2), binomial))
  }
  
  # Calculate AIC for all predictor variables
  aic_imp <- apply(pa120_c[,1:19], 2, var.imp, response= pa120_c$Cluster_sample)
  
  # Names of sorted variables
  sort_imp <- names(sort(aic_imp))
  
  # Calculate correlation matrix if not provided in function call
  if (is.null(cor_mat)) {
    cor_mat <- cor(pa120_c[,1:19], method='spearman')
  }
  
  # Identifies correlated variable pairs:
  diag(cor_mat)=NA
  pairs <- which(abs(cor_mat)>= threshold, arr.ind=T) 
  
  # Identify which variables should be excluded
  exclude <- NULL
  for (i in 1:length(sort_imp))
  {
    if ((sort_imp[i] %in% row.names(pairs))&
        ((sort_imp[i] %in% exclude)==F)) {
      cv <- cor_mat[setdiff(row.names(cor_mat),exclude),sort_imp[i]]
      cv <- cv[setdiff(names(cv),sort_imp[1:i])]
      exclude <- c(exclude,names(which((abs(cv)>=threshold)))) 
    }
  }
  
  # Select set of weakly correlated predictors:
  pred_sel <- sort_imp[!(sort_imp %in% exclude)]
  
  # Return list with AIC, correlation matrix, and final predictors:
  return(list(AIC=sort(aic_imp), cor_mat=cor_mat, pred_sel=pred_sel))
}

var_sel <- select07(pred_names=clim_vars, response_name=sp, data=avi_dfst, cor_mat=cor_mat, threshold=0.7)

pred_sel <- var_sel$pred_sel


###################################################################################
##  3.Sampling response variables (presence data) wild
###################################################################################

#### SAMPLE WILD ENSET DATA ALL #####

#read txt file with wild enset records
Even_wild_all<-read.csv("PATH/SDM/R/Data/presences/original/ALL_wild_enset_unique_xy.csv",header=TRUE)
write.csv(Even_wild_all, "PATH/SDM/R/Data/presences/original/ALL_wild_enset_xy_nr.csv")
Even_wild_all_nr<-read.csv("PATH/SDM/R/Data/presences/original/ALL_wild_enset_xy_nr.csv",header=TRUE)

#stack explanatory variables for reference area
Expl_reference_all<-stack(ch_bio01_reference,
                          ch_bio02_reference,
                          ch_bio03_reference,
                          ch_bio04_reference,
                          ch_bio05_reference,
                          ch_bio06_reference,
                          ch_bio07_reference,
                          ch_bio08_reference,
                          ch_bio09_reference,
                          ch_bio10_reference,
                          ch_bio11_reference,
                          ch_bio12_reference,
                          ch_bio13_reference,
                          ch_bio14_reference,
                          ch_bio15_reference,
                          ch_bio16_reference,
                          ch_bio17_reference,
                          ch_bio18_reference,
                          ch_bio19_reference)

#extract explanatory variables at wild presences
Even_wild2_expl<-extract(ch_bio_5arcmin_study_reg,Even_wild_all, df=TRUE)
Even_wild2_expl<-na.omit(Even_wild2_expl)

#devide BIOCLIM variables by sd
Even_wild_bio05_sd<- sapply(Even_wild2_expl$ch_bio05_agg,function(x){x/sd(Even_wild2_expl$ch_bio05_agg)})
Even_wild_bio12_sd<- sapply(Even_wild2_expl$ch_bio12_agg,function(x){x/sd(Even_wild2_expl$ch_bio12_agg)})
Even_wild_bio17_sd<- sapply(Even_wild2_expl$ch_bio17_agg,function(x){x/sd(Even_wild2_expl$ch_bio17_agg)})

Even_wild2_expl_sd<-cbind(Even_wild_bio05_sd,
                          Even_wild_bio12_sd,
                          Even_wild_bio17_sd)




##pca
Even_wild2_pca<-dudi.pca(Even_wild2_expl_sd,scannf = FALSE,nf=2)
get_eig(Even_wild2_pca)
head(Even_wild2_pca$li)
plot(Even_wild2_pca$li)

Even_wild2_presences_rr<-unique(Even_wild2_pca$li)
write.csv(Even_wild2_presences_rr, "PATH/SDM/R/Data/presences/Even_wild2_presences_unique.csv")
Even_wild2_presences_rr<-read.csv("PATH/SDM/R/Data/presences/Even_wild2_presences_unique.csv")
write.csv(Even_wild2_presences_rr,"PATH/SDM/R/Data/presences/Even_wild2_presences_unique_nr.csv")
Even_wild2_presences_rr_nr<-read.csv("PATH/SDM/R/Data/presences/Even_wild2_presences_unique_nr.csv", header = TRUE)
Even_wild2_presences_rr_training63<-sample_n(Even_wild2_presences_rr,63)
Even_wild2_presences_pca_training63<-cbind(Even_wild2_presences_rr_training63$Axis1, Even_wild2_presences_rr_training63$Axis2)


Even_wild_all_nr63<-setDT(Even_wild_all_nr)[Nr%in%Even_wild2_presences_rr_training63$X]
Even_wild2_presences_rr_training63<-cbind(Even_wild_all_nr63, Even_wild2_presences_rr_training63)
write.csv(Even_wild2_presences_rr_training63, "PATH/SDM/R/Data/presences/sample/wild2_sample_training63.csv")

###################################################################################
## 4.Preparation of bioclimatic variables
###################################################################################


library(raster)
library(rgdal)
library(Rmisc)

# import boundary of study region 
boundary_study_reg<-readOGR("PATH/SDM/GIS/shapes/study_area_lakes_new.shp")

# import boundary of reference area
boundary_reference_eth<-readOGR("PATH/SDM/GIS/shapes/reference_area_eth.shp")
boundary_reference_agroclim<-readOGR("PATH/SDM/GIS/shapes/agroclim_eth2.shp")
boundary_reference_agroclim_w2<-readOGR("PATH/SDM/GIS/shapes/background_w2_agroclim.shp")

# import boundary of transfer area
boundary_transfer_eth<-readOGR("PATH/SDM/GIS/shapes/transfer_area_eth2.shp")
boundary_transfer_agroclim<-readOGR("PATH/SDM/GIS/shapes/transfer_area_agroclim2.shp")
writeOGR(boundary_transfer_agroclim,"PATH/SDM/GIS/shapes/transfer_area_agroclim2.shp", "transfer_area_agroclim3", driver = "ESRI Shapefile")
### present climate ###

#import chelsa present climate rasters 5 arcmin resolution
ch_bio04<-raster("PATH/SDM/Data/Chelsa_res10x10/ch_bio04_agg")
ch_bio05<-raster("PATH/SDM/Data/Chelsa_res10x10/ch_bio05_agg")
ch_bio12<-raster("PATH/SDM/Data/Chelsa_res10x10/ch_bio12_agg")
ch_bio17<-raster("PATH/SDM/Data/Chelsa_res10x10/ch_bio17_agg")
ch_bio19<-raster("PATH/SDM/Data/Chelsa_res10x10/ch_bio19_agg")

ch_bio_5arcmin <- stack(ch_bio05, ch_bio12, ch_bio17)


ch_bio05_10arcmin<-aggregate(ch_bio05, fact=2, fun=mean)
ch_bio12_10arcmin<-aggregate(ch_bio12, fact=2, fun=mean)
ch_bio17_10arcmin<-aggregate(ch_bio17, fact=2, fun=mean)

# mask climate rasters to extent of study region
ch_bio04_5arcmin_study_reg<-mask(ch_bio04, boundary_study_reg)
ch_bio05_5arcmin_study_reg<-mask(ch_bio05, boundary_study_reg)
ch_bio12_5arcmin_study_reg<-mask(ch_bio12, boundary_study_reg)
ch_bio17_5arcmin_study_reg<-mask(ch_bio17, boundary_study_reg)
ch_bio19_5arcmin_study_reg<-mask(ch_bio19, boundary_study_reg)

# crop climate rasters to extent of study region
ch_bio04_5arcmin_study_reg<-crop(ch_bio04_5arcmin_study_reg, boundary_study_reg)
ch_bio05_5arcmin_study_reg<-crop(ch_bio05_5arcmin_study_reg, boundary_study_reg)
ch_bio12_5arcmin_study_reg<-crop(ch_bio12_5arcmin_study_reg, boundary_study_reg)
ch_bio17_5arcmin_study_reg<-crop(ch_bio17_5arcmin_study_reg, boundary_study_reg)
ch_bio19_5arcmin_study_reg<-crop(ch_bio19_5arcmin_study_reg, boundary_study_reg)

ch_bio_5arcmin_study_reg <- stack(ch_bio05_5arcmin_study_reg, 
                                   ch_bio12_5arcmin_study_reg, 
                                   ch_bio17_5arcmin_study_reg)

writeRaster(ch_bio04_5arcmin_study_reg, "PATH/SDM/R/plots_new_clean/data/ch_bio04_5arcmin_study_reg.tif")
writeRaster(ch_bio05_5arcmin_study_reg, "PATH/SDM/R/plots_new_clean/data/ch_bio05_5arcmin_study_reg.tif")
writeRaster(ch_bio12_5arcmin_study_reg, "PATH/SDM/R/plots_new_clean/data/ch_bio12_5arcmin_study_reg.tif")
writeRaster(ch_bio17_5arcmin_study_reg, "PATH/SDM/R/plots_new_clean/data/ch_bio17_5arcmin_study_reg.tif")
writeRaster(ch_bio19_5arcmin_study_reg, "PATH/SDM/R/plots_new_clean/data/ch_bio19_5arcmin_study_reg.tif")

# mask climate rasters to extent of boundary reference
ch_bio05_5arcmin_reference<-mask(ch_bio05, boundary_reference_agroclim)
ch_bio12_5arcmin_reference<-mask(ch_bio12, boundary_reference_agroclim)
ch_bio17_5arcmin_reference<-mask(ch_bio17, boundary_reference_agroclim)

# crop climate rasters to extent of boundary reference
ch_bio05_5arcmin_reference<-crop(ch_bio05_5arcmin_reference, boundary_reference_agroclim)
ch_bio12_5arcmin_reference<-crop(ch_bio12_5arcmin_reference, boundary_reference_agroclim)
ch_bio17_5arcmin_reference<-crop(ch_bio17_5arcmin_reference, boundary_reference_agroclim)


ch_bio_5arcmin_reference <- stack(ch_bio05_5arcmin_reference, 
                                  ch_bio12_5arcmin_reference, 
                                  ch_bio17_5arcmin_reference)




# mask climate rasters to extent of boundary reference222
ch_bio05_5arcmin_reference_w2<-mask(ch_bio05, boundary_reference_agroclim_w2)
ch_bio12_5arcmin_reference_w2<-mask(ch_bio12, boundary_reference_agroclim_w2)
ch_bio17_5arcmin_reference_w2<-mask(ch_bio17, boundary_reference_agroclim_w2)

# crop climate rasters to extent of boundary reference 222
ch_bio05_5arcmin_reference_w2<-crop(ch_bio05_5arcmin_reference_w2, boundary_reference_agroclim_w2)
ch_bio12_5arcmin_reference_w2<-crop(ch_bio12_5arcmin_reference_w2, boundary_reference_agroclim_w2)
ch_bio17_5arcmin_reference_w2<-crop(ch_bio17_5arcmin_reference_w2, boundary_reference_agroclim_w2)

ch_bio_5arcmin_reference_w2 <- stack(ch_bio05_5arcmin_reference_w2, 
                                  ch_bio12_5arcmin_reference_w2, 
                                  ch_bio17_5arcmin_reference_w2)



# mask climate rasters to extent of boundary transfer
ch_bio05_5arcmin_transfer<-mask(ch_bio05, boundary_transfer_agroclim)
ch_bio12_5arcmin_transfer<-mask(ch_bio12, boundary_transfer_agroclim)
ch_bio17_5arcmin_transfer<-mask(ch_bio17, boundary_transfer_agroclim)


# crop climate rasters to extent of boundary transfer
ch_bio05_5arcmin_transfer<-crop(ch_bio05_5arcmin_transfer, boundary_transfer_agroclim)
ch_bio12_5arcmin_transfer<-crop(ch_bio12_5arcmin_transfer, boundary_transfer_agroclim)
ch_bio17_5arcmin_transfer<-crop(ch_bio17_5arcmin_transfer, boundary_transfer_agroclim)


ch_bio_5arcmin_transfer <- stack(ch_bio05_5arcmin_transfer, 
                                  ch_bio12_5arcmin_transfer, 
                                  ch_bio17_5arcmin_transfer)


####future climate#####

###load data 2041-2060 rcp4.5####
ch_bio05_4160_rcp4.5 <- 
  raster::stack(
    c(
      CESM1_BGC  = "Data/Chelsa/RCP4.5/2041-2060/CHELSA_bio_mon_CESM1-BGC_rcp45_r1i1p1_g025.nc_5_2041-2060_V1.2.tif",
      CESM1_CAM5  = "Data/Chelsa/RCP4.5/2041-2060/CHELSA_bio_mon_CESM1-CAM5_rcp45_r1i1p1_g025.nc_5_2041-2060_V1.2.tif",
      CMCC_CM = "Data/Chelsa/RCP4.5/2041-2060/CHELSA_bio_mon_CMCC-CM_rcp45_r1i1p1_g025.nc_5_2041-2060_V1.2.tif",
      MIROC5 = "Data/Chelsa/RCP4.5/2041-2060/CHELSA_bio_mon_MIROC5_rcp45_r1i1p1_g025.nc_5_2041-2060_V1.2.tif",
      MPI_ESM_MR = "Data/Chelsa/RCP4.5/2041-2060/CHELSA_bio_mon_MPI-ESM-MR_rcp45_r1i1p1_g025.nc_5_2041-2060_V1.2.tif"
    )
  )

ch_bio12_4160_rcp4.5 <- 
  raster::stack(
    c(
      CESM1_BGC  = "Data/Chelsa/RCP4.5/2041-2060/CHELSA_bio_mon_CESM1-BGC_rcp45_r1i1p1_g025.nc_12_2041-2060_V1.2.tif",
      CESM1_CAM5  = "Data/Chelsa/RCP4.5/2041-2060/CHELSA_bio_mon_CESM1-CAM5_rcp45_r1i1p1_g025.nc_12_2041-2060_V1.2.tif",
      CMCC_CM = "Data/Chelsa/RCP4.5/2041-2060/CHELSA_bio_mon_CMCC-CM_rcp45_r1i1p1_g025.nc_12_2041-2060_V1.2.tif",
      MIROC5 = "Data/Chelsa/RCP4.5/2041-2060/CHELSA_bio_mon_MIROC5_rcp45_r1i1p1_g025.nc_12_2041-2060_V1.2.tif",
      MPI_ESM_MR = "Data/Chelsa/RCP4.5/2041-2060/CHELSA_bio_mon_MPI-ESM-MR_rcp45_r1i1p1_g025.nc_12_2041-2060_V1.2.tif"
    )
  )

ch_bio17_4160_rcp4.5 <- 
  raster::stack(
    c(
      CESM1_BGC  = "Data/Chelsa/RCP4.5/2041-2060/CHELSA_bio_mon_CESM1-BGC_rcp45_r1i1p1_g025.nc_17_2041-2060_V1.2.tif",
      CESM1_CAM5  = "Data/Chelsa/RCP4.5/2041-2060/CHELSA_bio_mon_CESM1-CAM5_rcp45_r1i1p1_g025.nc_17_2041-2060_V1.2.tif",
      CMCC_CM = "Data/Chelsa/RCP4.5/2041-2060/CHELSA_bio_mon_CMCC-CM_rcp45_r1i1p1_g025.nc_17_2041-2060_V1.2.tif",
      MIROC5 = "Data/Chelsa/RCP4.5/2041-2060/CHELSA_bio_mon_MIROC5_rcp45_r1i1p1_g025.nc_17_2041-2060_V1.2.tif",
      MPI_ESM_MR = "Data/Chelsa/RCP4.5/2041-2060/CHELSA_bio_mon_MPI-ESM-MR_rcp45_r1i1p1_g025.nc_17_2041-2060_V1.2.tif"
    )
  )

###load data 2041-2060 rcp8.5####
ch_bio05_4160_rcp8.5 <- 
  raster::stack(
    c(
      CESM1_BGC  = "Data/Chelsa/RCP8.5/2041-2060/CHELSA_bio_mon_CESM1-BGC_rcp85_r1i1p1_g025.nc_5_2041-2060_V1.2.tif",
      CESM1_CAM5  = "Data/Chelsa/RCP8.5/2041-2060/CHELSA_bio_mon_CESM1-CAM5_rcp85_r1i1p1_g025.nc_5_2041-2060_V1.2.tif",
      CMCC_CM = "Data/Chelsa/RCP8.5/2041-2060/CHELSA_bio_mon_CMCC-CM_rcp85_r1i1p1_g025.nc_5_2041-2060_V1.2.tif",
      MIROC5 = "Data/Chelsa/RCP8.5/2041-2060/CHELSA_bio_mon_MIROC5_rcp85_r1i1p1_g025.nc_5_2041-2060_V1.2.tif",
      MPI_ESM_MR = "Data/Chelsa/RCP8.5/2041-2060/CHELSA_bio_mon_MPI-ESM-MR_rcp85_r1i1p1_g025.nc_5_2041-2060_V1.2.tif"
    )
  )

ch_bio12_4160_rcp8.5 <- 
  raster::stack(
    c(
      CESM1_BGC  = "Data/Chelsa/RCP8.5/2041-2060/CHELSA_bio_mon_CESM1-BGC_rcp85_r1i1p1_g025.nc_12_2041-2060_V1.2.tif",
      CESM1_CAM5  = "Data/Chelsa/RCP8.5/2041-2060/CHELSA_bio_mon_CESM1-CAM5_rcp85_r1i1p1_g025.nc_12_2041-2060_V1.2.tif",
      CMCC_CM = "Data/Chelsa/RCP8.5/2041-2060/CHELSA_bio_mon_CMCC-CM_rcp85_r1i1p1_g025.nc_12_2041-2060_V1.2.tif",
      MIROC5 = "Data/Chelsa/RCP8.5/2041-2060/CHELSA_bio_mon_MIROC5_rcp85_r1i1p1_g025.nc_12_2041-2060_V1.2.tif",
      MPI_ESM_MR = "Data/Chelsa/RCP8.5/2041-2060/CHELSA_bio_mon_MPI-ESM-MR_rcp85_r1i1p1_g025.nc_12_2041-2060_V1.2.tif"
    )
  )

ch_bio17_4160_rcp8.5 <- 
  raster::stack(
    c(
      CESM1_BGC  = "Data/Chelsa/RCP8.5/2041-2060/CHELSA_bio_mon_CESM1-BGC_rcp85_r1i1p1_g025.nc_17_2041-2060_V1.2.tif",
      CESM1_CAM5  = "Data/Chelsa/RCP8.5/2041-2060/CHELSA_bio_mon_CESM1-CAM5_rcp85_r1i1p1_g025.nc_17_2041-2060_V1.2.tif",
      CMCC_CM = "Data/Chelsa/RCP8.5/2041-2060/CHELSA_bio_mon_CMCC-CM_rcp85_r1i1p1_g025.nc_17_2041-2060_V1.2.tif",
      MIROC5 = "Data/Chelsa/RCP8.5/2041-2060/CHELSA_bio_mon_MIROC5_rcp85_r1i1p1_g025.nc_17_2041-2060_V1.2.tif",
      MPI_ESM_MR = "Data/Chelsa/RCP8.5/2041-2060/CHELSA_bio_mon_MPI-ESM-MR_rcp85_r1i1p1_g025.nc_17_2041-2060_V1.2.tif"
    )
  )


###load data 2061-2080 rcp4.5####
ch_bio05_6180_rcp4.5 <- 
  raster::stack(
    c(
      CESM1_BGC  = "Data/Chelsa/RCP4.5/2061-2080/CHELSA_bio_mon_CESM1-BGC_rcp45_r1i1p1_g025.nc_5_2061-2080_V1.2.tif",
      CESM1_CAM5  = "Data/Chelsa/RCP4.5/2061-2080/CHELSA_bio_mon_CESM1-CAM5_rcp45_r1i1p1_g025.nc_5_2061-2080_V1.2.tif",
      CMCC_CM = "Data/Chelsa/RCP4.5/2061-2080/CHELSA_bio_mon_CMCC-CM_rcp45_r1i1p1_g025.nc_5_2061-2080_V1.2.tif",
      MIROC5 = "Data/Chelsa/RCP4.5/2061-2080/CHELSA_bio_mon_MIROC5_rcp45_r1i1p1_g025.nc_5_2061-2080_V1.2.tif",
      MPI_ESM_MR = "Data/Chelsa/RCP4.5/2061-2080/CHELSA_bio_mon_MPI-ESM-MR_rcp45_r1i1p1_g025.nc_5_2061-2080_V1.2.tif"
    )
  )

ch_bio12_6180_rcp4.5 <- 
  raster::stack(
    c(
      CESM1_BGC  = "Data/Chelsa/RCP4.5/2061-2080/CHELSA_bio_mon_CESM1-BGC_rcp45_r1i1p1_g025.nc_12_2061-2080_V1.2.tif",
      CESM1_CAM5  = "Data/Chelsa/RCP4.5/2061-2080/CHELSA_bio_mon_CESM1-CAM5_rcp45_r1i1p1_g025.nc_12_2061-2080_V1.2.tif",
      CMCC_CM = "Data/Chelsa/RCP4.5/2061-2080/CHELSA_bio_mon_CMCC-CM_rcp45_r1i1p1_g025.nc_12_2061-2080_V1.2.tif",
      MIROC5 = "Data/Chelsa/RCP4.5/2061-2080/CHELSA_bio_mon_MIROC5_rcp45_r1i1p1_g025.nc_12_2061-2080_V1.2.tif",
      MPI_ESM_MR = "Data/Chelsa/RCP4.5/2061-2080/CHELSA_bio_mon_MPI-ESM-MR_rcp45_r1i1p1_g025.nc_12_2061-2080_V1.2.tif"
    )
  )

ch_bio17_6180_rcp4.5 <- 
  raster::stack(
    c(
      CESM1_BGC  = "Data/Chelsa/RCP4.5/2061-2080/CHELSA_bio_mon_CESM1-BGC_rcp45_r1i1p1_g025.nc_17_2061-2080_V1.2.tif",
      CESM1_CAM5  = "Data/Chelsa/RCP4.5/2061-2080/CHELSA_bio_mon_CESM1-CAM5_rcp45_r1i1p1_g025.nc_17_2061-2080_V1.2.tif",
      CMCC_CM = "Data/Chelsa/RCP4.5/2061-2080/CHELSA_bio_mon_CMCC-CM_rcp45_r1i1p1_g025.nc_17_2061-2080_V1.2.tif",
      MIROC5 = "Data/Chelsa/RCP4.5/2061-2080/CHELSA_bio_mon_MIROC5_rcp45_r1i1p1_g025.nc_17_2061-2080_V1.2.tif",
      MPI_ESM_MR = "Data/Chelsa/RCP4.5/2061-2080/CHELSA_bio_mon_MPI-ESM-MR_rcp45_r1i1p1_g025.nc_17_2061-2080_V1.2.tif"
    )
  )

###load data 2061-2080 rcp8.5####
ch_bio05_6180_rcp8.5 <- 
  raster::stack(
    c(
      CESM1_BGC  = "Data/Chelsa/RCP8.5/2061-2080/CHELSA_bio_mon_CESM1-BGC_rcp85_r1i1p1_g025.nc_5_2061-2080_V1.2.tif",
      CESM1_CAM5  = "Data/Chelsa/RCP8.5/2061-2080/CHELSA_bio_mon_CESM1-CAM5_rcp85_r1i1p1_g025.nc_5_2061-2080_V1.2.tif",
      CMCC_CM = "Data/Chelsa/RCP8.5/2061-2080/CHELSA_bio_mon_CMCC-CM_rcp85_r1i1p1_g025.nc_5_2061-2080_V1.2.tif",
      MIROC5 = "Data/Chelsa/RCP8.5/2061-2080/CHELSA_bio_mon_MIROC5_rcp85_r1i1p1_g025.nc_5_2061-2080_V1.2.tif",
      MPI_ESM_MR = "Data/Chelsa/RCP8.5/2061-2080/CHELSA_bio_mon_MPI-ESM-MR_rcp85_r1i1p1_g025.nc_5_2061-2080_V1.2.tif"
    )
  )

ch_bio12_6180_rcp8.5 <- 
  raster::stack(
    c(
      CESM1_BGC  = "Data/Chelsa/RCP8.5/2061-2080/CHELSA_bio_mon_CESM1-BGC_rcp85_r1i1p1_g025.nc_12_2061-2080_V1.2.tif",
      CESM1_CAM5  = "Data/Chelsa/RCP8.5/2061-2080/CHELSA_bio_mon_CESM1-CAM5_rcp85_r1i1p1_g025.nc_12_2061-2080_V1.2.tif",
      CMCC_CM = "Data/Chelsa/RCP8.5/2061-2080/CHELSA_bio_mon_CMCC-CM_rcp85_r1i1p1_g025.nc_12_2061-2080_V1.2.tif",
      MIROC5 = "Data/Chelsa/RCP8.5/2061-2080/CHELSA_bio_mon_MIROC5_rcp85_r1i1p1_g025.nc_12_2061-2080_V1.2.tif",
      MPI_ESM_MR = "Data/Chelsa/RCP8.5/2061-2080/CHELSA_bio_mon_MPI-ESM-MR_rcp85_r1i1p1_g025.nc_12_2061-2080_V1.2.tif"
    )
  )

ch_bio17_6180_rcp8.5 <- 
  raster::stack(
    c(
      CESM1_BGC  = "Data/Chelsa/RCP8.5/2061-2080/CHELSA_bio_mon_CESM1-BGC_rcp85_r1i1p1_g025.nc_17_2061-2080_V1.2.tif",
      CESM1_CAM5  = "Data/Chelsa/RCP8.5/2061-2080/CHELSA_bio_mon_CESM1-CAM5_rcp85_r1i1p1_g025.nc_17_2061-2080_V1.2.tif",
      CMCC_CM = "Data/Chelsa/RCP8.5/2061-2080/CHELSA_bio_mon_CMCC-CM_rcp85_r1i1p1_g025.nc_17_2061-2080_V1.2.tif",
      MIROC5 = "Data/Chelsa/RCP8.5/2061-2080/CHELSA_bio_mon_MIROC5_rcp85_r1i1p1_g025.nc_17_2061-2080_V1.2.tif",
      MPI_ESM_MR = "Data/Chelsa/RCP8.5/2061-2080/CHELSA_bio_mon_MPI-ESM-MR_rcp85_r1i1p1_g025.nc_17_2061-2080_V1.2.tif"
    )
  )


### aggregate #####
ch_bio05_4160_rcp4.5_agg<-aggregate(ch_bio05_4160_rcp4.5, fact=10, fun=mean)
ch_bio12_4160_rcp4.5_agg<-aggregate(ch_bio12_4160_rcp4.5, fact=10, fun=mean)
ch_bio17_4160_rcp4.5_agg<-aggregate(ch_bio17_4160_rcp4.5, fact=10, fun=mean)

ch_bio05_4160_rcp8.5_agg<-aggregate(ch_bio05_4160_rcp8.5, fact=10, fun=mean)
ch_bio12_4160_rcp8.5_agg<-aggregate(ch_bio12_4160_rcp8.5, fact=10, fun=mean)
ch_bio17_4160_rcp8.5_agg<-aggregate(ch_bio17_4160_rcp8.5, fact=10, fun=mean)

ch_bio05_6180_rcp4.5_agg<-aggregate(ch_bio05_6180_rcp4.5, fact=10, fun=mean)
ch_bio12_6180_rcp4.5_agg<-aggregate(ch_bio12_6180_rcp4.5, fact=10, fun=mean)
ch_bio17_6180_rcp4.5_agg<-aggregate(ch_bio17_6180_rcp4.5, fact=10, fun=mean)

ch_bio05_6180_rcp8.5_agg<-aggregate(ch_bio05_6180_rcp8.5, fact=10, fun=mean)
ch_bio12_6180_rcp8.5_agg<-aggregate(ch_bio12_6180_rcp8.5, fact=10, fun=mean)
ch_bio17_6180_rcp8.5_agg<-aggregate(ch_bio17_6180_rcp8.5, fact=10, fun=mean)


####mask with study region#####
ch_bio05_4160_rcp4.5_agg<-mask(ch_bio05_4160_rcp4.5_agg, boundary_study_reg)
ch_bio12_4160_rcp4.5_agg<-mask(ch_bio12_4160_rcp4.5_agg, boundary_study_reg)
ch_bio17_4160_rcp4.5_agg<-mask(ch_bio17_4160_rcp4.5_agg, boundary_study_reg)

ch_bio05_4160_rcp8.5_agg<-mask(ch_bio05_4160_rcp8.5_agg, boundary_study_reg)
ch_bio12_4160_rcp8.5_agg<-mask(ch_bio12_4160_rcp8.5_agg, boundary_study_reg)
ch_bio17_4160_rcp8.5_agg<-mask(ch_bio17_4160_rcp8.5_agg, boundary_study_reg)

ch_bio05_6180_rcp4.5_agg<-mask(ch_bio05_6180_rcp4.5_agg, boundary_study_reg)
ch_bio12_6180_rcp4.5_agg<-mask(ch_bio12_6180_rcp4.5_agg, boundary_study_reg)
ch_bio17_6180_rcp4.5_agg<-mask(ch_bio17_6180_rcp4.5_agg, boundary_study_reg)

ch_bio05_6180_rcp8.5_agg<-mask(ch_bio05_6180_rcp8.5_agg, boundary_study_reg)
ch_bio12_6180_rcp8.5_agg<-mask(ch_bio12_6180_rcp8.5_agg, boundary_study_reg)
ch_bio17_6180_rcp8.5_agg<-mask(ch_bio17_6180_rcp8.5_agg, boundary_study_reg)

####crop with study region#####
ch_bio05_4160_rcp4.5_agg<-crop(ch_bio05_4160_rcp4.5_agg, boundary_study_reg)
ch_bio12_4160_rcp4.5_agg<-crop(ch_bio12_4160_rcp4.5_agg, boundary_study_reg)
ch_bio17_4160_rcp4.5_agg<-crop(ch_bio17_4160_rcp4.5_agg, boundary_study_reg)

ch_bio05_4160_rcp8.5_agg<-crop(ch_bio05_4160_rcp8.5_agg, boundary_study_reg)
ch_bio12_4160_rcp8.5_agg<-crop(ch_bio12_4160_rcp8.5_agg, boundary_study_reg)
ch_bio17_4160_rcp8.5_agg<-crop(ch_bio17_4160_rcp8.5_agg, boundary_study_reg)

ch_bio05_6180_rcp4.5_agg<-crop(ch_bio05_6180_rcp4.5_agg, boundary_study_reg)
ch_bio12_6180_rcp4.5_agg<-crop(ch_bio12_6180_rcp4.5_agg, boundary_study_reg)
ch_bio17_6180_rcp4.5_agg<-crop(ch_bio17_6180_rcp4.5_agg, boundary_study_reg)

ch_bio05_6180_rcp8.5_agg<-crop(ch_bio05_6180_rcp8.5_agg, boundary_study_reg)
ch_bio12_6180_rcp8.5_agg<-crop(ch_bio12_6180_rcp8.5_agg, boundary_study_reg)
ch_bio17_6180_rcp8.5_agg<-crop(ch_bio17_6180_rcp8.5_agg, boundary_study_reg)




####get mean between model projections####

ch_bio05_4160_rcp4.5_mean<-calc(ch_bio05_4160_rcp4.5_agg, fun = mean, na.rm = T)
ch_bio12_4160_rcp4.5_mean<-calc(ch_bio12_4160_rcp4.5_agg, fun = mean, na.rm = T)
ch_bio17_4160_rcp4.5_mean<-calc(ch_bio17_4160_rcp4.5_agg, fun = mean, na.rm = T)

ch_bio05_4160_rcp8.5_mean<-calc(ch_bio05_4160_rcp8.5_agg, fun = mean, na.rm = T)
ch_bio12_4160_rcp8.5_mean<-calc(ch_bio12_4160_rcp8.5_agg, fun = mean, na.rm = T)
ch_bio17_4160_rcp8.5_mean<-calc(ch_bio17_4160_rcp8.5_agg, fun = mean, na.rm = T)

ch_bio05_6180_rcp4.5_mean<-calc(ch_bio05_6180_rcp4.5_agg, fun = mean, na.rm = T)
ch_bio12_6180_rcp4.5_mean<-calc(ch_bio12_6180_rcp4.5_agg, fun = mean, na.rm = T)
ch_bio17_6180_rcp4.5_mean<-calc(ch_bio17_6180_rcp4.5_agg, fun = mean, na.rm = T)

ch_bio05_6180_rcp8.5_mean<-calc(ch_bio05_6180_rcp8.5_agg, fun = mean, na.rm = T)
ch_bio12_6180_rcp8.5_mean<-calc(ch_bio12_6180_rcp8.5_agg, fun = mean, na.rm = T)
ch_bio17_6180_rcp8.5_mean<-calc(ch_bio17_6180_rcp8.5_agg, fun = mean, na.rm = T)


writeRaster(ch_bio05_4160_rcp4.5_mean, "PATH/SDM/R/Data/future_climate/ch_bio05_4160_rcp4.5_mean.tif")
writeRaster(ch_bio12_4160_rcp4.5_mean, "PATH/SDM/R/Data/future_climate/ch_bio12_4160_rcp4.5_mean.tif")
writeRaster(ch_bio17_4160_rcp4.5_mean, "PATH/SDM/R/Data/future_climate/ch_bio17_4160_rcp4.5_mean.tif")

writeRaster(ch_bio05_4160_rcp8.5_mean, "PATH/SDM/R/Data/future_climate/ch_bio05_4160_rcp8.5_mean.tif")
writeRaster(ch_bio12_4160_rcp8.5_mean, "PATH/SDM/R/Data/future_climate/ch_bio12_4160_rcp8.5_mean.tif")
writeRaster(ch_bio17_4160_rcp8.5_mean, "PATH/SDM/R/Data/future_climate/ch_bio17_4160_rcp8.5_mean.tif")

writeRaster(ch_bio05_6180_rcp4.5_mean, "PATH/SDM/R/Data/future_climate/ch_bio05_6180_rcp4.5_mean.tif")
writeRaster(ch_bio12_6180_rcp4.5_mean, "PATH/SDM/R/Data/future_climate/ch_bio12_6180_rcp4.5_mean.tif")
writeRaster(ch_bio17_6180_rcp4.5_mean, "PATH/SDM/R/Data/future_climate/ch_bio17_6180_rcp4.5_mean.tif")

writeRaster(ch_bio05_6180_rcp8.5_mean, "PATH/SDM/R/Data/future_climate/ch_bio05_6180_rcp8.5_mean.tif")
writeRaster(ch_bio12_6180_rcp8.5_mean, "PATH/SDM/R/Data/future_climate/ch_bio12_6180_rcp8.5_mean.tif")
writeRaster(ch_bio17_6180_rcp8.5_mean, "PATH/SDM/R/Data/future_climate/ch_bio17_6180_rcp8.5_mean.tif")







                             