     ##### Ensemble Modelling #######

library(biomod2)
library(dismo)
library(raster)
library(ggplot2)
library(ade4)
library(rasterVis)
     
     
setwd("PATH/SDM/R")  
##############################
##### Domesticated Enset #####
##############################
# 0. Load data & Selecting Data


# species occurrences domesticated enset
DataEnset60 <- read.csv("PATH/SDM/R/Data/presences/sample/enset_dom_sample60.csv")
head(DataEnset60)

# the name of studied species
RespName <- 'Ensete.ventricosum'

# the presence/absences data for our species
E_ventricosum_dom60 <- as.numeric(DataEnset60[,"Species"])

# the XY coordinates of species data
E_ventricosum_dom_XY60 <- DataEnset60[,c("Longitude","Latitude")]
head(E_ventricosum_dom_XY60)    


#Explanatory vatiables
#reference
Expl_reference_sel5 = stack( ch_bio05_reference,
                             ch_bio12_reference,
                             ch_bio17_reference)

#transfer
#present
Expl_study_reg_sel5 = stack( ch_bio05_study_reg,
                             ch_bio12_study_reg,
                             ch_bio17_study_reg)
#2050 rcp4.5
ch_bio_2050_rcp4.5<-stack(ch_bio05_4160_rcp4.5_mean,
                          ch_bio12_4160_rcp4.5_mean,
                          ch_bio17_4160_rcp4.5_mean)
#2050 rcp8.5
ch_bio_2050_rcp8.5<-stack(ch_bio05_4160_rcp8.5_mean,
                          ch_bio12_4160_rcp8.5_mean,
                          ch_bio17_4160_rcp8.5_mean)
#2070 rcp4.5
ch_bio_2070_rcp4.5<-stack(ch_bio05_6180_rcp4.5_mean,
                          ch_bio12_6180_rcp4.5_mean,
                          ch_bio17_6180_rcp4.5_mean)
#2070 rcp8.5
ch_bio_2070_rcp8.5<-stack(ch_bio05_6180_rcp8.5_mean,
                          ch_bio12_6180_rcp8.5_mean,
                          ch_bio17_6180_rcp8.5_mean)


names(ch_bio_2050_rcp4.5)[1:3]<-c("ch_bio05_agg", "ch_bio12_agg", "ch_bio17_agg")
names(ch_bio_2050_rcp8.5)[1:3]<-c("ch_bio05_agg", "ch_bio12_agg", "ch_bio17_agg")
names(ch_bio_2070_rcp4.5)[1:3]<-c("ch_bio05_agg", "ch_bio12_agg", "ch_bio17_agg")
names(ch_bio_2070_rcp8.5)[1:3]<-c("ch_bio05_agg", "ch_bio12_agg", "ch_bio17_agg")

# 1. Formatting Data


dom_rr60_Data_5arcmin <- BIOMOD_FormatingData (resp.var = E_ventricosum_dom60,
                                               expl.var = ch_bio_5arcmin_reference,
                                               resp.xy = E_ventricosum_dom_XY60,
                                               resp.name = RespName, 
                                               PA.nb.rep=10, 
                                               PA.nb.absences=1000, 
                                               PA.strategy="random")



# 2. Defining Models Options
myBiomodOption <- BIOMOD_ModelingOptions(GAM = list(k=3),
                                         MAXENT.Phillips =list (path_to_maxent.jar = 'C:/Users/Lenovo/Documents/Studium/maxent',
                                                                product=TRUE,
                                                                hinge=FALSE)
)

# 3. Doing Modelisation

#domesticated enset

dom_rr60_ModelOut_5arcmin <- BIOMOD_Modeling( dom_rr60_Data_5arcmin,
                                              models = c('GLM',"GAM","GBM","MARS",'RF',"MAXENT.Phillips"),
                                              models.options = myBiomodOption,
                                              NbRunEval=5,
                                              DataSplit=70,
                                              Yweights=NULL,
                                              Prevalence=0.5,
                                              VarImport=3,
                                              models.eval.meth = c('TSS',"ROC"),
                                              SaveObj = TRUE,
                                              rescal.all.models = FALSE,
                                              do.full.models = FALSE,
                                              modeling.id = "dom_rr60_5arcmin")
# 4. Doing Ensemble Modelling

#domesticated enset

dom_rr60_EM_5arcmin <- BIOMOD_EnsembleModeling( modeling.output = dom_rr60_ModelOut_5arcmin,
                                                chosen.models = c("all"),
                                                em.by = 'all',
                                                eval.metric = c('all'),
                                                eval.metric.quality.threshold = c(0.60,0.80),
                                                models.eval.meth = c('TSS','ROC'),
                                                prob.mean = TRUE,
                                                prob.cv = TRUE,
                                                prob.ci = FALSE,
                                                prob.ci.alpha = 0.05,
                                                prob.median = FALSE,
                                                committee.averaging = FALSE,
                                                prob.mean.weight = TRUE,
                                                prob.mean.weight.decay = 'proportional',
                                                VarImport=3)   
# 5. doing projections   

#domesticated enset
#present

dom_rr60_Projection_5arcmin <- BIOMOD_Projection(modeling.output = dom_rr60_ModelOut_5arcmin,
                                                 new.env = ch_bio_5arcmin_study_reg,
                                                 proj.name = 'current.dom_rr60_5arcmin',
                                                 selected.models = 'all',
                                                 binary.meth = 'TSS',
                                                 compress = FALSE,
                                                 output.format = ".img",
                                                 do.stack=FALSE)

#2050 rcp4.5
dom_rr60_Projection_5arcmin_2050_rcp4.5 <- BIOMOD_Projection(modeling.output = dom_rr60_ModelOut_5arcmin,
                                                             new.env = ch_bio_2050_rcp4.5,
                                                             proj.name = 'dom_rr60_5arcmin_2050.rcp4.5',
                                                             selected.models = 'all',
                                                             binary.meth = 'TSS',
                                                             compress = FALSE,
                                                             output.format = ".img",
                                                             do.stack=FALSE)
#2050 rcp8.5
dom_rr60_Projection_5arcmin_2050_rcp8.5 <- BIOMOD_Projection(modeling.output = dom_rr60_ModelOut_5arcmin,
                                                             new.env = ch_bio_2050_rcp8.5,
                                                             proj.name = 'dom_rr60_5arcmin_2050.rcp8.5',
                                                             selected.models = 'all',
                                                             binary.meth = 'TSS',
                                                             compress = FALSE,
                                                             output.format = ".img",
                                                             do.stack=FALSE)
#2070 rcp4.5
dom_rr60_Projection_5arcmin_2070_rcp4.5 <- BIOMOD_Projection(modeling.output = dom_rr60_ModelOut_5arcmin,
                                                             new.env = ch_bio_2070_rcp4.5,
                                                             proj.name = 'dom_rr60_5arcmin_2070.rcp4.5',
                                                             selected.models = 'all',
                                                             binary.meth = 'TSS',
                                                             compress = FALSE,
                                                             output.format = ".img",
                                                             do.stack=FALSE)
#2070 rcp8.5
dom_rr60_Projection_5arcmin_2070_rcp8.5 <- BIOMOD_Projection(modeling.output = dom_rr60_ModelOut_5arcmin,
                                                             new.env = ch_bio_2070_rcp8.5,
                                                             proj.name = 'dom_rr60_5arcmin_2070.rcp8.5',
                                                             selected.models = 'all',
                                                             binary.meth = 'TSS',
                                                             compress = FALSE,
                                                             output.format = ".img",
                                                             do.stack=FALSE)



# 6. ensemble forecasting  

#domesticated enset
#present
dom_rr60_EF_5arcmin <- BIOMOD_EnsembleForecasting(
    EM.output = dom_rr60_EM_5arcmin,
    projection.output = dom_rr60_Projection_5arcmin,
    binary.meth="TSS", 
    output.format = ".img",
    do.stack=FALSE
)

#2050 rcp4.5
dom_rr60_EF_2050_rcp4.5 <- BIOMOD_EnsembleForecasting(
    EM.output = dom_rr60_EM_5arcmin,
    projection.output = dom_rr60_Projection_5arcmin_2050_rcp4.5,
    binary.meth="TSS", 
    output.format = ".img",
    do.stack=FALSE
)
#2050 rcp8.5
dom_rr60_EF_2050_rcp8.5 <- BIOMOD_EnsembleForecasting(
    EM.output = dom_rr60_EM_5arcmin,
    projection.output = dom_rr60_Projection_5arcmin_2050_rcp8.5,
    binary.meth="TSS", 
    output.format = ".img",
    do.stack=FALSE
)
#2070 rcp4.5
dom_rr60_EF_2070_rcp4.5 <- BIOMOD_EnsembleForecasting(
    EM.output = dom_rr60_EM_5arcmin,
    projection.output = dom_rr60_Projection_5arcmin_2070_rcp4.5,
    binary.meth="TSS", 
    output.format = ".img",
    do.stack=FALSE
)
#2070 rcp8.5
dom_rr60_EF_2070_rcp8.5 <- BIOMOD_EnsembleForecasting(
    EM.output = dom_rr60_EM_5arcmin,
    projection.output = dom_rr60_Projection_5arcmin_2070_rcp8.5,
    binary.meth="TSS", 
    output.format = ".img",
    do.stack=FALSE
)







##############################
#####      Wild Enset    #####
##############################


# 0. Load data & Selecting Data
    
#Wild Enset  63
     # the XY coordinates of species data
     E_ventricosum_wild63xy<-read.csv("PATH/SDM/R/Data/presences/sample/wild2_sample_training63_xy.csv")
     E_ventricosum_wild63xy<-cbind(E_ventricosum_wild63xy$x,E_ventricosum_wild63xy$y)
     # the presence/absences data for our species
     n<-63
     E_ventricosum_wild63<-rep(1,n)    
     
 # the name of studied species
     RespName <- 'Ensete_ventricosum'  
     
 #Explanatory vatiables
     #reference
     Expl_reference_sel5 = stack( ch_bio05_reference,
                                  ch_bio12_reference,
                                  ch_bio17_reference)
     
     #transfer
     
     ch_bio05_4160_rcp4.5_mean<- raster( "PATH/SDM/R/Data/future_climate/ch_bio05_4160_rcp4.5_mean.tif")
     ch_bio12_4160_rcp4.5_mean<- raster( "PATH/SDM/R/Data/future_climate/ch_bio12_4160_rcp4.5_mean.tif")
     ch_bio17_4160_rcp4.5_mean<- raster( "PATH/SDM/R/Data/future_climate/ch_bio17_4160_rcp4.5_mean.tif")
     
     ch_bio05_4160_rcp8.5_mean<- raster( "PATH/SDM/R/Data/future_climate/ch_bio05_4160_rcp8.5_mean.tif")
     ch_bio12_4160_rcp8.5_mean<- raster( "PATH/SDM/R/Data/future_climate/ch_bio12_4160_rcp8.5_mean.tif")
     ch_bio17_4160_rcp8.5_mean<- raster( "PATH/SDM/R/Data/future_climate/ch_bio17_4160_rcp8.5_mean.tif")
     
     ch_bio05_6180_rcp4.5_mean<- raster( "PATH/SDM/R/Data/future_climate/ch_bio05_6180_rcp4.5_mean.tif")
     ch_bio12_6180_rcp4.5_mean<- raster( "PATH/SDM/R/Data/future_climate/ch_bio12_6180_rcp4.5_mean.tif")
     ch_bio17_6180_rcp4.5_mean<- raster( "PATH/SDM/R/Data/future_climate/ch_bio17_6180_rcp4.5_mean.tif")
     
     ch_bio05_6180_rcp8.5_mean<- raster( "PATH/SDM/R/Data/future_climate/ch_bio05_6180_rcp8.5_mean.tif")
     ch_bio12_6180_rcp8.5_mean<- raster( "PATH/SDM/R/Data/future_climate/ch_bio12_6180_rcp8.5_mean.tif")
     ch_bio17_6180_rcp8.5_mean<- raster( "PATH/SDM/R/Data/future_climate/ch_bio17_6180_rcp8.5_mean.tif")
     
         #present
         Expl_study_reg_sel5 = stack( ch_bio05_study_reg,
                                      ch_bio12_study_reg,
                                      ch_bio17_study_reg)
         #2050 rcp4.5
         ch_bio_2050_rcp4.5<-stack(ch_bio05_4160_rcp4.5_mean,
                                   ch_bio12_4160_rcp4.5_mean,
                                   ch_bio17_4160_rcp4.5_mean)
         #2050 rcp8.5
         ch_bio_2050_rcp8.5<-stack(ch_bio05_4160_rcp8.5_mean,
                                   ch_bio12_4160_rcp8.5_mean,
                                   ch_bio17_4160_rcp8.5_mean)
         #2070 rcp4.5
         ch_bio_2070_rcp4.5<-stack(ch_bio05_6180_rcp4.5_mean,
                                   ch_bio12_6180_rcp4.5_mean,
                                   ch_bio17_6180_rcp4.5_mean)
         #2070 rcp8.5
         ch_bio_2070_rcp8.5<-stack(ch_bio05_6180_rcp8.5_mean,
                                   ch_bio12_6180_rcp8.5_mean,
                                   ch_bio17_6180_rcp8.5_mean)
         
         names(ch_bio_2050_rcp4.5)[1:3]<-c("ch_bio05_agg", "ch_bio12_agg", "ch_bio17_agg")
         names(ch_bio_2050_rcp8.5)[1:3]<-c("ch_bio05_agg", "ch_bio12_agg", "ch_bio17_agg")
         names(ch_bio_2070_rcp4.5)[1:3]<-c("ch_bio05_agg", "ch_bio12_agg", "ch_bio17_agg")
         names(ch_bio_2070_rcp8.5)[1:3]<-c("ch_bio05_agg", "ch_bio12_agg", "ch_bio17_agg")
     
# 1. Formatting Data
     
     
     #wild enset 5 arcmin resolution agroclim 
     
     wild2_rr63_Data_5arcmin <- BIOMOD_FormatingData (resp.var = E_ventricosum_wild63,
                                                    expl.var = ch_bio_5arcmin_reference_w2,
                                                    resp.xy = E_ventricosum_wild63xy,
                                                    resp.name = RespName, 
                                                    PA.nb.rep=10, 
                                                    PA.nb.absences=1000, 
                                                    PA.strategy="random")
     
     
# 2. Defining Models Options
     myBiomodOption <- BIOMOD_ModelingOptions(GAM = list(k=3),
                                              MAXENT.Phillips =list (path_to_maxent.jar = 'C:/Users/Lenovo/Documents/Studium/maxent',
                                                                     product=TRUE,
                                                                     hinge=FALSE)
     )
     
# 3. Doing Modelisation
     
    
     #wild enset
     
     wild2_rr63_ModelOut_5arcmin <- BIOMOD_Modeling( wild2_rr63_Data_5arcmin,
                                                   models = c('GLM',"GAM","GBM","MARS",'RF',"MAXENT.Phillips"),
                                                   models.options = myBiomodOption,
                                                   NbRunEval=5,
                                                   DataSplit=70,
                                                   Yweights=NULL,
                                                   Prevalence=0.5,
                                                   VarImport=3,
                                                   models.eval.meth = c('TSS',"ROC"),
                                                   SaveObj = TRUE,
                                                   rescal.all.models = FALSE,
                                                   do.full.models = FALSE,
                                                   modeling.id = "wild2_rr63_5arcmin")
     
     
    
     wild2_rr63_ModelOut_5arcmin2 <- BIOMOD_Modeling( wild2_rr63_Data_5arcmin2,
                                                    models = c('GLM',"GAM","GBM","MARS",'RF',"MAXENT.Phillips"),
                                                    models.options = myBiomodOption,
                                                    NbRunEval=5,
                                                    DataSplit=70,
                                                    Yweights=NULL,
                                                    Prevalence=0.5,
                                                    VarImport=3,
                                                    models.eval.meth = c('TSS',"ROC"),
                                                    SaveObj = TRUE,
                                                    rescal.all.models = FALSE,
                                                    do.full.models = FALSE,
                                                    modeling.id = "wild2_rr63_5arcmin2")
 
# 4. Doing Ensemble Modelling
     
     #wild enset
     wild_rr_EM_5arcmin <- BIOMOD_EnsembleModeling( modeling.output = wild_rr_ModelOut_5arcmin,
                                                chosen.models = c("all"),
                                                em.by = 'all',
                                                eval.metric = c('all'),
                                                eval.metric.quality.threshold = c(0.60,0.80),
                                                models.eval.meth = c('TSS','ROC'),
                                                prob.mean = TRUE,
                                                prob.cv = TRUE,
                                                prob.ci = FALSE,
                                                prob.ci.alpha = 0.05,
                                                prob.median = FALSE,
                                                committee.averaging = FALSE,
                                                prob.mean.weight = TRUE,
                                                prob.mean.weight.decay = 'proportional',
                                                VarImport=3)
     
     wild2_rr_EM_5arcmin <- BIOMOD_EnsembleModeling( modeling.output = wild2_rr_ModelOut_5arcmin,
                                                    chosen.models = c("all"),
                                                    em.by = 'all',
                                                    eval.metric = c('all'),
                                                    eval.metric.quality.threshold = c(0.60,0.80),
                                                    models.eval.meth = c('TSS','ROC'),
                                                    prob.mean = TRUE,
                                                    prob.cv = TRUE,
                                                    prob.ci = FALSE,
                                                    prob.ci.alpha = 0.05,
                                                    prob.median = FALSE,
                                                    committee.averaging = FALSE,
                                                    prob.mean.weight = TRUE,
                                                    prob.mean.weight.decay = 'proportional',
                                                    VarImport=3)
     
     wild2_rr63_EM_5arcmin <- BIOMOD_EnsembleModeling( modeling.output = wild2_rr63_ModelOut_5arcmin,
                                                     chosen.models = c("all"),
                                                     em.by = 'all',
                                                     eval.metric = c('all'),
                                                     eval.metric.quality.threshold = c(0.60,0.80),
                                                     models.eval.meth = c('TSS','ROC'),
                                                     prob.mean = TRUE,
                                                     prob.cv = TRUE,
                                                     prob.ci = FALSE,
                                                     prob.ci.alpha = 0.05,
                                                     prob.median = FALSE,
                                                     committee.averaging = FALSE,
                                                     prob.mean.weight = TRUE,
                                                     prob.mean.weight.decay = 'proportional',
                                                     VarImport=3)

     wild2_rr63_EM_5arcmin2 <- BIOMOD_EnsembleModeling( modeling.output = wild2_rr63_ModelOut_5arcmin2,
                                                      chosen.models = c("all"),
                                                      em.by = 'all',
                                                      eval.metric = c('all'),
                                                      eval.metric.quality.threshold = c(0.60,0.80),
                                                      models.eval.meth = c('TSS','ROC'),
                                                      prob.mean = TRUE,
                                                      prob.cv = TRUE,
                                                      prob.ci = FALSE,
                                                      prob.ci.alpha = 0.05,
                                                      prob.median = FALSE,
                                                      committee.averaging = FALSE,
                                                      prob.mean.weight = TRUE,
                                                      prob.mean.weight.decay = 'proportional',
                                                      VarImport=3)

     
# 5. doing projections   
     
                 
     #wild enset (present)
    
     wild2_rr63_Projection_5arcmin <- BIOMOD_Projection(modeling.output = wild2_rr63_ModelOut_5arcmin,
                                                      new.env = ch_bio_5arcmin_study_reg,
                                                      proj.name = 'current.wild2_rr63_5arcmin',
                                                      selected.models = 'all',
                                                      binary.meth = 'TSS',
                                                      compress = FALSE,
                                                      output.format = ".img",
                                                      do.stack=FALSE)

     
     #2050 rcp4.5
     wild2_rr63_Projection_5arcmin_2050_rcp4.5 <- BIOMOD_Projection(modeling.output = wild2_rr63_ModelOut_5arcmin,
                                                                new.env = ch_bio_2050_rcp4.5,
                                                                proj.name = 'wild2_rr63_5arcmin_2050.rcp4.5',
                                                                selected.models = 'all',
                                                                binary.meth = 'TSS',
                                                                compress = FALSE,
                                                                output.format = ".img",
                                                                do.stack=FALSE)
     #2050 rcp8.5
     wild2_rr63_Projection_5arcmin_2050_rcp8.5 <- BIOMOD_Projection(modeling.output = wild2_rr63_ModelOut_5arcmin,
                                                                new.env = ch_bio_2050_rcp8.5,
                                                                proj.name = 'wild2_rr63_5arcmin_2050.rcp8.5',
                                                                selected.models = 'all',
                                                                binary.meth = 'TSS',
                                                                compress = FALSE,
                                                                output.format = ".img",
                                                                do.stack=FALSE)
     #2070 rcp4.5
     wild2_rr63_Projection_5arcmin_2070_rcp4.5 <- BIOMOD_Projection(modeling.output = wild2_rr63_ModelOut_5arcmin,
                                                                new.env = ch_bio_2070_rcp4.5,
                                                                proj.name = 'wild2_rr63_5arcmin_2070.rcp4.5',
                                                                selected.models = 'all',
                                                                binary.meth = 'TSS',
                                                                compress = FALSE,
                                                                output.format = ".img",
                                                                do.stack=FALSE)
     #2070 rcp8.5
     wild2_rr63_Projection_5arcmin_2070_rcp8.5 <- BIOMOD_Projection(modeling.output = wild2_rr63_ModelOut_5arcmin,
                                                                new.env = ch_bio_2070_rcp8.5,
                                                                proj.name = 'wild2_rr63_5arcmin_2070.rcp8.5',
                                                                selected.models = 'all',
                                                                binary.meth = 'TSS',
                                                                compress = FALSE,
                                                                output.format = ".img",
                                                                do.stack=FALSE)
     
# 6. ensemble forecasting  
     
  
     #wild enset (present)

     wild2_rr63_EF_5arcmin <- BIOMOD_EnsembleForecasting(
         EM.output = wild2_rr63_EM_5arcmin,
         projection.output = wild2_rr63_Projection_5arcmin,
         binary.meth="TSS", 
         output.format = ".img",
         do.stack=FALSE
     ) 
     

     #2050 rcp4.5
     wild2_rr63_EF_2050_rcp4.5 <- BIOMOD_EnsembleForecasting(
         EM.output = wild2_rr63_EM_5arcmin,
         projection.output = wild2_rr63_Projection_5arcmin_2050_rcp4.5,
         binary.meth="TSS", 
         output.format = ".img",
         do.stack=FALSE
     )
     #2050 rcp8.5
     wild2_rr63_EF_2050_rcp8.5 <- BIOMOD_EnsembleForecasting(
         EM.output = wild2_rr63_EM_5arcmin,
         projection.output = wild2_rr63_Projection_5arcmin_2050_rcp8.5,
         binary.meth="TSS", 
         output.format = ".img",
         do.stack=FALSE
     )
     #2070 rcp4.5
     wild2_rr63_EF_2070_rcp4.5 <- BIOMOD_EnsembleForecasting(
         EM.output = wild2_rr63_EM_5arcmin,
         projection.output = wild2_rr63_Projection_5arcmin_2070_rcp4.5,
         binary.meth="TSS", 
         output.format = ".img",
         do.stack=FALSE
     )
     #2070 rcp8.5
     wild2_rr63_EF_2070_rcp8.5 <- BIOMOD_EnsembleForecasting(
         EM.output = wild2_rr63_EM_5arcmin,
         projection.output = wild2_rr63_Projection_5arcmin_2070_rcp8.5,
         binary.meth="TSS", 
         output.format = ".img",
         do.stack=FALSE
     )
     
     