                  
######### Identification of priority areas ########


library(dismo)
library(ggplot2)
library(scater)
library(coefplot)
library(raster)
library(rgdal)


##########################################################################################
###  1. Refine  crop projetions by cropland and protected areas IUCN cat I,II         ####
##########################################################################################
#### 1.1 crop projetions by protected areas ####

WDPA_clip<-readOGR("PATH/SDM/GIS/shapes/WDPA_Aug2020-shapefile/WDPA_clip.shp")
WDPA_clip_bio12<-mask(ch_bio12, WDPA_clip)
WDPA_clip_bio12<-crop(WDPA_clip_bio12, WDPA_clip)

WDPA_clip_bio12_resample<-resample(WDPA_clip_bio12, dom_rr60_bin_proj_current, method="bilinear")

writeRaster(WDPA_clip_bio12_resample,"PATH/SDM/GIS/raster/WDPA_clip_bio12_resample.tif")

WDPA_resample<-readOGR("PATH/SDM/GIS/shapes/WDPA_resample.shp")

no_WDPA<-gDifference(boundary_study_reg, WDPA_resample)


#### 1.2 crop projections to cropland outside of protected areas ####
setwd("PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff")
all_crops_all_list <- list.files(pattern='\\.tif$')
crop_area_spam <- stack(all_crops_all_list)

crop_area_spam<-mask(crop_area_spam, boundary_study_reg)
crop_area_spam<-crop(crop_area_spam, boundary_study_reg)
crop_area_spam_sum<-calc(crop_area_spam, fun = sum, na.rm = T)
crop_area_spam_sum_class<-reclassify( crop_area_spam_sum, c(-Inf, 0, 0,  0, Inf, 1))
crop_area_spam_sum_res<-resample(crop_area_spam_sum, ef_rr60_5arcmin_EMwmeanByTSS, method="ngb")

crop_area_spam_sum_class_res<-resample(crop_area_spam_sum_class, ef_rr60_5arcmin_EMwmeanByTSS, method="ngb")

crop_area_spam_sum_class_res_nWDPA<-mask(crop_area_spam_sum_class_res, no_WDPA)
crop_area_spam_sum_class_res_nWDPA<-crop(crop_area_spam_sum_class_res_nWDPA, no_WDPA)

writeRaster(crop_area_spam_sum_res,"PATH/SDM/GIS/raster/crop_area_spam_sum.tif")
writeRaster(crop_area_spam_sum_class_res,"PATH/SDM/GIS/raster/crop_area_spam_sum_class.tif")
writeRaster(crop_area_spam_sum_class_res_nWDPA,"PATH/SDM/GIS/raster/crop_area_spam_sum_class_nWDPA.tif")


spam_cropland_nWDPA_shp<-readOGR("PATH/SDM/GIS/shapes/spam_cropland_nWDPA.shp")
spam_cropland_shp_nWDPA<-crop(spam_cropland_shp, no_WDPA)


#####################################################################
####     2. prepare data for identification of priority areas    ####
#####################################################################
#### 2.1 population ####

pop_count<-raster("PATH/SDM/GIS/raster/pop_count/w001001.adf")

pop_count_agg<-aggregate(pop_count, fact=10, fun=sum)

pop_count_agg<-mask(pop_count_agg, boundary_study_reg)
pop_count_agg<-crop(pop_count_agg, boundary_study_reg)

pop_count_agg_resample<-resample(pop_count_agg, dom_rr60_bin_proj_current, method="bilinear")
hist(pop_count_agg_resample, plot=FALSE)
pop_count_agg_resample_vals<-values(pop_count_agg_resample)
mean(pop_count_agg_resample)
median(pop_count_agg_resample_vals, na.rm = T)
quantile(pop_count_agg_resample_vals, na.rm = T)
quantile(pop_count_agg_resample_vals, probs=c(0.05,0.95),na.rm = T)
writeRaster(pop_count_agg_resample,"PATH/SDM/GIS/raster/pop_count_agg_resample.tif")
pop_count_agg_resample<-raster("PATH/SDM/GIS/raster/pop_count_agg_resample.tif")

##classes
pop_count_agg_resample_class <- reclassify(pop_count_agg_resample, c(-Inf, 10000, 0,  10000, 20000, 1, 20000, Inf, 2))

writeRaster(pop_count_agg_resample_class, "PATH/SDM/GIS/raster/pop_count_agg_resample_class.tif")


#### 2.2 seasonal food shortage ####
dom_rr60_bin_proj_current_cropl_nWDPA<-raster("PATH/SDM/GIS/raster/proj_refined/dom_rr60_bin_proj_current_cropl_nWDPA.tif")
IPC_stressed_raster<-raster("PATH/SDM/GIS/raster/IPC_stressed.tif")
IPC_stressed_raster_resample<-resample(IPC_stressed_raster, dom_rr60_bin_proj_current_cropl_nWDPA, method="bilinear")
writeRaster(IPC_stressed_raster_resample,"PATH/SDM/GIS/raster/IPC_stressed_resample.tif")

#classes
IPC_stressed_raster_resample_class <- reclassify(IPC_stressed_raster_resample, c(-Inf, 2, 1,  2, Inf, 2))
IPC_stressed_raster_resample_class<-extend(IPC_stressed_raster_resample_class,boundary_study_reg, value=0 )
IPC_stressed_raster_resample_class<-mask(IPC_stressed_raster_resample_class,boundary_study_reg)
IPC_stressed_raster_resample_class<-crop(IPC_stressed_raster_resample_class,boundary_study_reg)
writeRaster(IPC_stressed_raster_resample_class, "PATH/SDM/GIS/raster/IPC_stressed_raster_resample_class.tif")



#### 2.3 crop diversity ####
crops_prod_L <- 
  raster::stack(
    c(BARL_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_BARL_L.tif",
      BEAN_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_BEAN_L.tif",
      CASS_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_CASS_L.tif",
      CHIC_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_CHIC_L.tif",
      COWP_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_COWP_L.tif",
      LENT_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_LENT_L.tif",
      MAIZ_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_MAIZ_L.tif",
      OCER_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_OCER_L.tif",
      OPUL_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_OPUL_L.tif",
      ORTS_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_ORTS_L.tif",
      PIGE_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_PIGE_L.tif",
      PLNT_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_PLNT_L.tif",
      PMIL_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_PMIL_L.tif",
      POTA_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_POTA_L.tif",
      REST_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_REST_L.tif",
      RICE_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_RICE_L.tif",
      SMIL_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_SMIL_L.tif",
      SORG_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_SORG_L.tif",
      SWPO_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_SWPO_L.tif",
      WHEA_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_WHEA_L.tif",
      YAMS_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_YAMS_L.tif"
    )
  )

crops_prod_S <- 
  raster::stack(
    c(BARL_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_BARL_S.tif",
      BEAN_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_BEAN_S.tif",
      CASS_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_CASS_S.tif",
      CHIC_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_CHIC_S.tif",
      COWP_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_COWP_S.tif",
      LENT_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_LENT_S.tif",
      MAIZ_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_MAIZ_S.tif",
      OCER_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_OCER_S.tif",
      OPUL_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_OPUL_S.tif",
      ORTS_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_ORTS_S.tif",
      PIGE_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_PIGE_S.tif",
      PLNT_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_PLNT_S.tif",
      PMIL_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_PMIL_S.tif",
      POTA_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_POTA_S.tif",
      REST_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_REST_S.tif",
      RICE_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_RICE_S.tif",
      SMIL_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_SMIL_S.tif",
      SORG_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_SORG_S.tif",
      SWPO_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_SWPO_S.tif",
      WHEA_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_WHEA_S.tif",
      YAMS_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_prod.geotiff/spam2017V2r1_SSA_P_YAMS_S.tif"
    )
  )



crops_prod_LS<-overlay(crops_prod_L,crops_prod_S, fun=function(x,y){return(x+y)}, unstack=TRUE, na.rm = T)
crops_prod_LS<-mask(crops_prod_LS,boundary_study_reg)
crops_prod_LS<-crop(crops_prod_LS,boundary_study_reg)

crops_prod_LS_sum<-sum(crops_prod_LS)
crops_prod_LS_sum<-mask(crops_prod_LS_sum,boundary_study_reg)
crops_prod_LS_sum<-crop(crops_prod_LS_sum,boundary_study_reg)

crops_prod_LS_share<-overlay(crops_prod_LS,crops_prod_LS_sum, fun=function(x,y){return(x/y)},na.rm = T, unstack=TRUE)
crops_prod_LS_share<-mask(crops_prod_LS_share,boundary_study_reg)
crops_prod_LS_share<-crop(crops_prod_LS_share,boundary_study_reg)
crops_prod_LS_harelog<-overlay(crops_prod_LS_share, fun=function(x){return(x*log(x))},na.rm = T, unstack=TRUE)

crops_prod_LS_H<- -sum(crops_prod_LS_harelog, na.rm = T)

crops_prod_LS_H2<-crops_prod_LS_H

#classes
quantile(crops_prod_LS_H2, probs=c(0.333,0.666),na.rm = T)
diversity_crops_prod_LS_H_class<-reclassify(crops_prod_LS_H2, c(-Inf, 0.688607504, 2,  0.688607504, 1.230236246, 1, 1.230236246, Inf, 0))


###caregorize priority layers
##lanuse
#### 2.4 prevalence of subsistence and low input agriculture #####

#load crop are raster files
crops_area_stack <- 
  raster::stack(
    c(
      ACOF_L  = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_ACOF_L.tif",
      ACOF_S  = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_ACOF_S.tif",
      BANA_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_BANA_L.tif",
      BANA_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_BANA_S.tif",
      BARL_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_BARL_L.tif",
      BARL_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_BARL_S.tif",
      BEAN_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_BEAN_L.tif",
      BEAN_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_BEAN_S.tif",
      CASS_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_CASS_L.tif",
      CASS_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_CASS_S.tif",
      CHIC_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_CHIC_L.tif",
      CHIC_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_CHIC_S.tif",
      CNUT_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_CNUT_L.tif",
      CNUT_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_CNUT_S.tif",
      COCO_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_COCO_L.tif",
      COCO_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_COCO_S.tif",
      COTT_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_COTT_L.tif",
      COTT_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_COTT_S.tif",
      COWP_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_COWP_L.tif",
      COWP_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_COWP_S.tif",
      GROU_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_GROU_L.tif",
      GROU_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_GROU_S.tif",
      LENT_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_LENT_L.tif",
      LENT_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_LENT_S.tif",
      MAIZ_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_MAIZ_L.tif",
      MAIZ_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_MAIZ_S.tif",
      OCER_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_OCER_L.tif",
      OCER_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_OCER_S.tif",
      OFIB_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_OFIB_L.tif",
      OFIB_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_OFIB_S.tif",
      OILP_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_OILP_L.tif",
      OILP_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_OILP_S.tif",
      OOIL_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_OOIL_L.tif",
      OOIL_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_OOIL_S.tif",
      OPUL_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_OPUL_L.tif",
      OPUL_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_OPUL_S.tif",
      ORTS_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_ORTS_L.tif",
      ORTS_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_ORTS_S.tif",
      PIGE_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_PIGE_L.tif",
      PIGE_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_PIGE_S.tif",
      PLNT_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_PLNT_L.tif",
      PLNT_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_PLNT_S.tif",
      PMIL_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_PMIL_L.tif",
      PMIL_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_PMIL_S.tif",
      POTA_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_POTA_L.tif",
      POTA_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_POTA_S.tif",
      RAPE_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_RAPE_L.tif",
      RAPE_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_RAPE_S.tif",
      RCOF_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_RCOF_L.tif",
      RCOF_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_RCOF_S.tif",
      REST_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_REST_L.tif",
      REST_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_REST_S.tif",
      RICE_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_RICE_L.tif",
      RICE_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_RICE_S.tif",
      SESA_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_SESA_L.tif",
      SESA_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_SESA_S.tif",
      SMIL_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_SMIL_L.tif",
      SMIL_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_SMIL_S.tif",
      SORG_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_SORG_L.tif",
      SORG_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_SORG_S.tif",
      SOYB_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_SOYB_L.tif",
      SOYB_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_SOYB_S.tif",
      SUGB_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_SUGB_L.tif",
      SUGB_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_SUGB_S.tif",
      SUGC_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_SUGC_L.tif",
      SUGC_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_SUGC_S.tif",
      SUNF_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_SUNF_L.tif",
      SUNF_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_SUNF_S.tif",
      SWPO_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_SWPO_L.tif",
      SWPO_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_SWPO_S.tif",
      TEAS_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_TEAS_L.tif",
      TEAS_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_TEAS_S.tif",
      TEMF_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_TEMF_L.tif",
      TEMF_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_TEMF_S.tif",
      TOBA_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_TOBA_L.tif",
      TOBA_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_TOBA_S.tif",
      TROF_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_TROF_L.tif",
      TROF_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_TROF_S.tif",
      VEGE_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_VEGE_L.tif",
      VEGE_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_VEGE_S.tif",
      WHEA_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_WHEA_L.tif",
      WHEA_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_WHEA_S.tif",
      YAMS_L = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_YAMS_L.tif",
      YAMS_S = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_YAMS_S.tif"
    )
  )

crops_area_alltec <- 
  raster::stack(
    c(
      ACOF_A  = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_ACOF_A.tif",
      BANA_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_BANA_A.tif",
      BARL_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_BARL_A.tif",
      BEAN_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_BEAN_A.tif",
      CASS_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_CASS_A.tif",
      CHIC_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_CHIC_A.tif",
      CNUT_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_CNUT_A.tif",
      COCO_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_COCO_A.tif",
      COTT_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_COTT_A.tif",
      COWP_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_COWP_A.tif",
      GROU_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_GROU_A.tif",
      LENT_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_LENT_A.tif",
      MAIZ_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_MAIZ_A.tif",
      OCER_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_OCER_A.tif",
      OFIB_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_OFIB_A.tif",
      OILP_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_OILP_A.tif",
      OOIL_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_OOIL_A.tif",
      OPUL_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_OPUL_A.tif",
      ORTS_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_ORTS_A.tif",
      PIGE_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_PIGE_A.tif",
      PLNT_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_PLNT_A.tif",
      PMIL_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_PMIL_A.tif",
      POTA_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_POTA_A.tif",
      RAPE_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_RAPE_A.tif",
      RCOF_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_RCOF_A.tif",
      REST_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_REST_A.tif",
      RICE_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_RICE_A.tif",
      SESA_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_SESA_A.tif",
      SMIL_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_SMIL_A.tif",
      SORG_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_SORG_A.tif",
      SOYB_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_SOYB_A.tif",
      SUGB_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_SUGB_A.tif",
      SUGC_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_SUGC_A.tif",
      SUNF_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_SUNF_A.tif",
      SWPO_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_SWPO_A.tif",
      TEAS_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_TEAS_A.tif",
      TEMF_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_TEMF_A.tif",
      TOBA_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_TOBA_A.tif",
      TROF_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_TROF_A.tif",
      VEGE_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_VEGE_A.tif",
      WHEA_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_WHEA_A.tif",
      YAMS_A = "PATH/SDM/GIS/raster/spam2017v2r1_ssa_phys_area.geotiff/spam2017V2r1_SSA_A_YAMS_A.tif"
    )
  )


subs_low_i_sum<-calc(crops_area_stack, fun = sum, na.rm = T)
crops_area_alltec_sum<-calc(crops_area_alltec, fun = sum, na.rm = T)
#mask
subs_low_i_sum<-mask(subs_low_i_sum, boundary_study_reg)
crops_area_alltec_sum<-mask(crops_area_alltec_sum, boundary_study_reg)
# crop
subs_low_i_sum<-crop(subs_low_i_sum, boundary_study_reg)
crops_area_alltec_sum<-crop(crops_area_alltec_sum, boundary_study_reg)

crops_tec<-stack(subs_low_i_sum, crops_area_alltec_sum)

fun<- function(x){x[1]/x[2]}

subs_low_i_share<-calc(crops_tec, fun)

#classes
subs_low_i_sum_class <- reclassify(subs_low_i_sum, c(-Inf, 500, 0,  500, 1000, 1,  1000, Inf, 2))
writeRaster(subs_low_i_sum_class, "C:/Users/Lenovo/Documents/Studium/Agroforestry and Food Security/Disseratation/SDM/GIS/raster/subs_low_i_sum_class.tif")


#########################################
###### 3.  combined priority maps  ######
#########################################

prio_tec_IPC_pop_div2<-stack(subs_low_i_sum_class,IPC_stressed_raster_resample_class,pop_count_agg_resample_class, diversity_crops_prod_LS_H_class )
prio_tec_IPC_pop_div2_sum<-calc(prio_tec_IPC_pop_div2, fun = sum, na.rm = T)
prio_tec_IPC_pop_div2_sum<-resample(prio_tec_IPC_pop_div2_sum, dom_rr60_bin_proj_current_cropl_nWDPA, method="ngb")
prio_tec_IPC_pop_div2_sum<-mask(prio_tec_IPC_pop_div2_sum, boundary_study_reg)
prio_tec_IPC_pop_div2_sum<-crop(prio_tec_IPC_pop_div2_sum, boundary_study_reg)
writeRaster(prio_tec_IPC_pop_div2_sum, "PATH/SDM/GIS/raster/prio_tec_IPC_pop_div_H_sum2.tif")

##classses
prio_tec_IPC_pop_div2_sum_class3 <- reclassify(prio_tec_IPC_pop_div2_sum, c(-Inf, 2, 0, 2, 5, 1, 5, 8, 2))
writeRaster(prio_tec_IPC_pop_div2_sum_class, "PATH/SDM/GIS/raster/prio_tec_IPC_pop_div2_sum_class.tif")



